==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Mudar para janela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Mudar para tela cheia</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Contagem Regressiva</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A gravação não foi iniciada, não há espaço suficiente no disco.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>O limite de espaço livre em disco foi atingido.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre no disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A gravação foi interrompida, não há espaço livre em disco.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gerenciador de arquivos.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>A sessão do desktop é Wayland</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>No momento, o protocolo de exibição Wayland não é suportado. A captura apresenta uma tela preta. Favor sair e iniciar uma nova sessão do X11 Desktop.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-Fonte</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doações</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Sessão com protocolo de exibição Wayland foi detectada</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Abrir Arquivo</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar na horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar na vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configurações da câmera</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem Regressiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamanho do vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espaço disponível no disco</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo de gravação:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de vídeo </translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de áudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do mouse</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar o cronômetro</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Para gravação após</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Diretório do vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre no disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar na área de notificação</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Espera em segundos antes de começar gravando</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Buscar atualizações</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Não disponível</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar relatório</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproduzir última gravação</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar ao iniciar a gravação</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar na horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar na vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doações</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Redefinir todas as configurações na próxima inicialização</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos autorais e licença das imagens</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Captura de Tela</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reprodutor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos autorais e licença das imagens</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir Arquivo</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Quadro anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Próximo quadro</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mover o menu</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Mudar para janela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Mudar para tela cheia</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gerenciador de arquivos.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A gravação não foi iniciada, não há espaço suficiente no disco.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>O limite de espaço livre em disco foi atingido.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre no disco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A gravação foi interrompida, não há espaço livre em disco.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Por favor instale um gerenciador de arquivos.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código-Fonte</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduções</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doações</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecione um ou mais dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zoom</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar na horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar na vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configurações da câmera</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Contagem Regressiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamanho do vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espaço disponível no disco</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo de gravação:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec de vídeo </translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec de áudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Não gravar o cursor do mouse</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar o cronômetro</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Para gravação após</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Diretório do vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limite de espaço livre no disco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar na área de notificação</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Espera em segundos antes de começar gravando</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Buscar atualizações</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Não disponível</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverter</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar relatório</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproduzir última gravação</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar ao iniciar a gravação</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Girar na horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Girar na vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Preto e branco</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remover moldura da janela</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doações</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Redefinir todas as configurações na próxima inicialização</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos autorais e licença das imagens</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Captura de Tela</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reprodutor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Direitos autorais e licença das imagens</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir Arquivo</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Quadro anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Próximo quadro</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mover o menu</translation>
    </message>
</context>
</TS>
